summaryrefslogtreecommitdiff
path: root/bfd/elf32-dlx.c
diff options
context:
space:
mode:
authorAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
committerAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
commitd9ec26b6578cfde9d7fb605787c9878ccd623893 (patch)
tree20a6a8bcbbf4b7822c06138f1ea37e335a09d5be /bfd/elf32-dlx.c
parent0a693b807e2990a20fcdc75692dd1f1ecd355be0 (diff)
downloadbinutils-redhat-d9ec26b6578cfde9d7fb605787c9878ccd623893.tar.gz
Correct spelling of "relocatable".
Diffstat (limited to 'bfd/elf32-dlx.c')
-rw-r--r--bfd/elf32-dlx.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/bfd/elf32-dlx.c b/bfd/elf32-dlx.c
index a1f7d0d48f..1f380e88ea 100644
--- a/bfd/elf32-dlx.c
+++ b/bfd/elf32-dlx.c
@@ -1,5 +1,5 @@
/* DLX specific support for 32-bit ELF
- Copyright 2002 Free Software Foundation, Inc.
+ Copyright 2002, 2003 Free Software Foundation, Inc.
This file is part of BFD, the Binary File Descriptor library.
@@ -320,7 +320,7 @@ _bfd_dlx_elf_hi16_reloc (abfd, reloc_entry, symbol, data,
return ret;
}
/* ELF relocs are against symbols. If we are producing relocateable
output, and the reloc is against an external symbol, and nothing
has given us any additional addend, the resulting reloc will also
be against the same symbol. In such a case, we don't want to
@@ -328,7 +328,7 @@ _bfd_dlx_elf_hi16_reloc (abfd, reloc_entry, symbol, data,
all be done at final link time. Rather than put special case code
into bfd_perform_relocation, all the reloc types use this howto
function. It just short circuits the reloc if producing
- relocateable output against an external symbol. */
+ relocatable output against an external symbol. */
static bfd_reloc_status_type
elf32_dlx_relocate16 (abfd, reloc_entry, symbol, data,
@@ -532,7 +532,7 @@ elf32_dlx_check_relocs (abfd, info, sec, relocs)
const Elf_Internal_Rela *rel;
const Elf_Internal_Rela *rel_end;
- if (info->relocateable)
+ if (info->relocatable)
return TRUE;
symtab_hdr = &elf_tdata (abfd)->symtab_hdr;
@@ -320,7 +320,7 @@ _bfd_dlx_elf_hi16_reloc (abfd, reloc_entry, symbol, data,
return ret;
}
-/* ELF relocs are against symbols. If we are producing relocateable
+/* ELF relocs are against symbols. If we are producing relocatable
output, and the reloc is against an external symbol, and nothing
has given us any additional addend, the resulting reloc will also